Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PlencDescriptorToProtobuf ¶
func PlencDescriptorToProtobuf(pd *plenccodec.Descriptor) (*descriptorpb.DescriptorProto, error)
Types ¶
type DiskReadManager ¶
type DiskReadManager struct {
// contains filtered or unexported fields
}
func NewDiskReadManager ¶
func (*DiskReadManager) Start ¶
func (drm *DiskReadManager) Start(ctx context.Context)
func (*DiskReadManager) Stop ¶
func (drm *DiskReadManager) Stop()
type Uploader ¶
type Uploader interface {
// bufferFor returns a buffer of exactly size bytes.
BufferFor(size int) []byte
// add is called to note that the buffer returned by bufferFor was used and
// is full of useful data,
Add(buf []byte)
Flush()
// TryFlush attempts to flush the buffer to the table writer. It will not spill to disk.
TryFlush()
}
type UploaderFactory ¶
Click to show internal directories.
Click to hide internal directories.